rm(list = ls())

# Figures (output directory figures)
# -boxplots AUC for CVD and T2D wrt MND
# -boxplots AUPRC for CVD and T2D wrt MND
# -Calibrations plots for CVD and T2D wrt selected MND

usePackage <- function(p) {
  if (!is.element(p, installed.packages()[,1]))
    install.packages(p, dep = TRUE)
  require(p, character.only = TRUE)
}


usePackage("Rmisc")
usePackage("magrittr")
usePackage("data.table")
usePackage("ggplot2")
usePackage("car")
usePackage("openxlsx")


#input data
input_res<-"output//results_glmnet_atc_icd_T2D.csv"

#output aggregated table of results
output_feat<-"reports//results_table_atc_icd_T2D.xlsx"

res_glmnet<-read.csv(input_res, stringsAsFactors = F)

Summary_table_ci<-function (data, measure, group1 ){
  
  
  for (i in 1:length(measure)){
    tab1<-summarySE(data , measurevar=measure[i], groupvars = group1)
    
    tmpN<-tab1$N
    
    est<-paste(format(round(tab1[,measure[i]],digits=3),nsmall=3), " (",
                    format(round(tab1[,measure[i]]-tab1$ci,digits=3),nsmall=3)," - ",
                    format(round(tab1[,measure[i]]+tab1$ci,digits=3),nsmall=3), ")",sep="") 
    tmp_tab<-data.frame(tab1[,group1], var= est)
    names(tmp_tab)<-c(group1,measure[i])
    
    if(i==1) {
      tab<-tmp_tab
      N<-data.table(tmpN)
    }else {
      tab<-cbind(tab, tmp_tab[,2] [match(tab [,group1], tmp_tab[,group1])])
      
      N<-cbind(N, tmpN)
  
    }
    
    
  }
  N<-apply(N,1,mean)
  names(tab)<-c(group1,measure)
  
  tab<-data.frame(Name=tab[,1], N=N, tab[,2:(length(measure)+1)])
  
  return(tab)
}

tab<-Summary_table_ci(res_glmnet,c("AUC","AUPRC","Sensitivity","Specificity","PPV","NPV","NumSelected","PercPos"),"Name")


output_tabela<-function(tmp_list,perc=0) {
  
  tmp_list<-sort(table(unlist(lapply(tmp_list, function(x) strsplit(x, ",")))),decreasing=T)
  n=length(tmp_list)
  if(length(tmp_list)==0) return(data.frame(drug_icd9_id="", Freq="",ATC="", drug_name="", icd9="",icd9_short="",
                                            Inter1="",Inter1_descr="",Inter2="",Inter2_descr="",row.names=NULL))
  tmp_list<-tmp_list[tmp_list>=n*perc]
  tmp_list<-tmp_list[!names(tmp_list)=="-" & !names(tmp_list)=="+"]
  
  res<-data.frame(Feature=names(tmp_list), Freq=as.vector(tmp_list),row.names=NULL)

  
  return(res)
} 



comb<-unique(res_glmnet$Name)

table_res<-list(tab)


for (i in 1: length(comb)) {
  
  data_list<-res_glmnet$Pred_Vars[res_glmnet$Name==comb[i]]
  #fixing error
  data_list<-gsub(" ",",",data_list)
  
  table_res<-c(table_res, list(output_tabela(data_list)))
  
}

names(table_res) <-c("Overview",paste0("MND=",sapply(strsplit(comb,"="),"[",2)))

#Sys.setenv(R_ZIPCMD= file.path(devtools:::get_rtools_path(),"zip"))
Sys.setenv(R_ZIPCMD= "C:/Program Files/Rtools/bin/zip")   
write.xlsx(table_res, file = output_feat)


