rm(list = ls())


usePackage <- function(p) {
  if (!is.element(p, installed.packages()[,1]))
    install.packages(p, dep = TRUE)
  require(p, character.only = TRUE)
}

#loading sources and libraries
source("val.prob.ci.2.r")

usePackage("rms")
usePackage("ModelGood")
usePackage("cowplot")
usePackage("data.table")
usePackage("car")

input_results_cvd<-"output\\results_glmnet_atc_icd_CVD.csv"
input_results_t2d<-"output\\results_glmnet_atc_icd_T2D.csv"

input_predict_cvd<-"output\\glmnet_calib_output_atc_icd_CVD.rds"
input_predict_t2d<-"output\\glmnet_calib_output_atc_icd_T2D.rds"
  
figure_boxplox_AUC<-"figures\\Boxplots of CVD and T2D AUC values with 100 iterations at different MND values_ATC_ICD.pdf"
figure_boxplox_AUPRC<-"figures\\Boxplots of CVD and T2D AUPRC values with 100 iterations at different MND values_ATC_ICD.pdf"
figure_calibration_plots<-"figures\\Calibration plots of CVD and T2D at different MND values_ATC_ICD.pdf"

predict_glmnet_atc_cvd<-readRDS(input_predict_cvd)
predict_glmnet_atc_t2d<-readRDS(input_predict_t2d)

output_results_cvd<-read.csv(input_results_cvd, stringsAsFactors = F)
output_results_t2d<-read.csv(input_results_t2d, stringsAsFactors = F)

MND_val<-c("10", "20","30","40","50","60","70", "80",  "90","100","NDR")   

data_CVD_T2D<-rbind(data.table(output_results_cvd,Type="CVD"),data.table(output_results_t2d,Type="T2D"))
data_CVD_T2D$MND_str<-sapply(strsplit(data_CVD_T2D$Name,"MND="),"[",2)
data_CVD_T2D$MND_str<-recode(data_CVD_T2D$MND_str,'"n"="NDR"')
data_CVD_T2D$MND_str<-factor(data_CVD_T2D$MND_str, levels=c("10", "20",  "30",  "40",  "50",  "60", "70",
                                                                        "80",  "90",  "100", "NDR")) 

#AUC
#Glmnet boxplot CVD and T2D AUC by MND
ggplot(data_CVD_T2D, aes(x=MND_str, y=AUC, fill=Type)) +
  geom_boxplot(position=position_dodge(1),size=0.75)+
  labs(title="",x="MND", y = "AUC")+
  theme_classic()+
  theme(legend.title = element_text(size = 15),plot.title = element_text(size = 15,hjust = 0.5),
        axis.title.x = element_text(size = 15),
        axis.title.y = element_text(size = 15,angle=90),axis.text.x=element_text(size = 15),
        axis.text.y = element_text(size = 12),legend.text = element_text(size=15),
        strip.text.x = element_text(size = 20),strip.text.y = element_text(size = 20),
        legend.direction = "horizontal", legend.position = "bottom" )+
        scale_fill_manual(name = "Type", values=alpha(c("darkblue", "darkred"),0.2))

#vector output for AUC
pdf(file=figure_boxplox_AUC,width = 12, height = 6)
ggplot(data_CVD_T2D, aes(x=MND_str, y=AUC, fill=Type)) +
  geom_boxplot(position=position_dodge(1),size=0.75)+
  # geom_jitter(position=position_jitter(width=0.3, height=0.2), aes(colour=factor(Type)), alpha=0.2) +
  labs(title="",x="MND", y = "AUC")+
  theme_classic()+
  theme(legend.title = element_text(size = 15),plot.title = element_text(size = 15,hjust = 0.5),
        axis.title.x = element_text(size = 15),
        axis.title.y = element_text(size = 15,angle=90),axis.text.x=element_text(size = 15),
        axis.text.y = element_text(size = 12),legend.text = element_text(size=15),
        strip.text.x = element_text(size = 20),strip.text.y = element_text(size = 20),
        legend.direction = "horizontal", legend.position = "bottom" )+
  scale_fill_manual(name = "Type", values=alpha(c("darkblue", "darkred"),0.2))
dev.off()

#AUPRC
#Glmnet boxplot CVD and T2D AUPRC by MND
ggplot(data_CVD_T2D, aes(x=MND_str, y=AUPRC, fill=Type)) +
  geom_boxplot(position=position_dodge(1),size=0.75)+
  labs(title="",x="MND", y = "AUPRC")+
  theme_classic()+
  theme(legend.title = element_text(size = 15),plot.title = element_text(size = 15,hjust = 0.5),
        axis.title.x = element_text(size = 15),
        axis.title.y = element_text(size = 15,angle=90),axis.text.x=element_text(size = 15),
        axis.text.y = element_text(size = 12),legend.text = element_text(size=12),
        strip.text.x = element_text(size = 20),strip.text.y = element_text(size = 20),
        legend.direction = "horizontal", legend.position = "bottom" )+
  scale_fill_manual(name = "Type", values=alpha(c("darkblue", "darkred"),0.2))

#vector output for AUPRC
pdf(file=figure_boxplox_AUPRC,width = 12, height = 6)
ggplot(data_CVD_T2D, aes(x=MND_str, y=AUPRC, fill=Type)) +
  geom_boxplot(position=position_dodge(1),size=0.75)+
  # geom_jitter(position=position_jitter(width=0.3, height=0.2), aes(colour=factor(Type)), alpha=0.2) +
  labs(title="",x="MND", y = "AUPRC")+
  theme_classic()+
  theme(legend.title = element_text(size = 15),plot.title = element_text(size = 15,hjust = 0.5),
        axis.title.x = element_text(size = 15),
        axis.title.y = element_text(size = 15,angle=90),axis.text.x=element_text(size = 15),
        axis.text.y = element_text(size = 12),legend.text = element_text(size=12),
        strip.text.x = element_text(size = 20),strip.text.y = element_text(size = 20),
        legend.direction = "horizontal", legend.position = "bottom" )+
  scale_fill_manual(name = "Type", values=alpha(c("darkblue", "darkred"),0.2))
dev.off()


MND_cvd=sapply(strsplit(colnames(predict_glmnet_atc_cvd),"MND="),"[",2)
MND_cvd<-recode(MND_cvd,'"n"="NDR"')

MND_t2d=sapply(strsplit(colnames(predict_glmnet_atc_t2d),"MND="),"[",2)
MND_t2d<-recode(MND_t2d,'"n"="NDR"')

#MND values printed in calibration plots
MND_val<-c("10", "20","50","100","NDR")    

.pardefault <- par()
#vector output for calibration plots
pdf(file=figure_calibration_plots,width = 8, height = 14)
par(mar=c(2,2.5,2.5,0.5))
par(mfrow = c(5, 2)) 
for(j in MND_val) {

  idx<-which(MND_cvd==j)
  if (j!=MND_val[length(MND_val)]) {
  val.prob.ci.2(predict_glmnet_atc_cvd[,idx[1]],predict_glmnet_atc_cvd[,idx[2]],smooth="rcs",
                     main=paste0("MND=",MND_cvd[idx[1]]),xaxt='n')
  } else {
    
    val.prob.ci.2(predict_glmnet_atc_cvd[,idx[1]],predict_glmnet_atc_cvd[,idx[2]],smooth="rcs",
                     main=paste0("MND=",MND_cvd[idx[1]])) 
    
  }
  
  idx<-which(MND_t2d==j)
  
  if (j!=MND_val[length(MND_val)]) {
  val.prob.ci.2(predict_glmnet_atc_t2d[,idx[1]],predict_glmnet_atc_t2d[,idx[2]],smooth="rcs",
                     main=paste0("MND=",MND_t2d[idx[1]]),xaxt='n',yaxt='n')

  } else {
    
    val.prob.ci.2(predict_glmnet_atc_t2d[,idx[1]],predict_glmnet_atc_t2d[,idx[2]],smooth="rcs",
                       main=paste0("MND=",MND_t2d[idx[1]]),yaxt='n')
    
  }

}
dev.off()
.pardefault <- par()



