rm(list = ls())

# 
# Overview for T2D data
# - input data: preprocessed data in rds format (in directory data) - must be supplied
# - output variable: poly
# - numeric variable: YearBirthPerson, also GenderPerson treated as numeric
# 
# Glmnet output (directory output):
#   -output for results table:	Name,	Model,	Fold,	Seed,	pmax,	AUC,	AUPRC,	Threshold,	Brier,	Accuracy,	Sensitivity,	Specificity,	PPV,	NPV,	NumSelected,	Zero_pred (nr. of removed columns with cases),	YLength,	YtLength,	YSum,	YtSum,	PercPos,	Pred_Vars (predictor variables in model with sign)
# 
# -output for calibration plot: for first seed (Probability predictions, True value 0/1) for each MND


usePackage <- function(p) {
  if (!is.element(p, installed.packages()[,1]))
    install.packages(p, dep = TRUE)
  require(p, character.only = TRUE)
}

#loading sources and libraries

source("evalGLMNET_calib.R")

usePackage("data.table")
usePackage("Matrix")
usePackage("car")
usePackage("ggplot2")
usePackage("caret")

#need to supply own input
input2<-"data\\data_T2D.rds"

#output glmnet results and output for calibration plots
output_glmnet_atc_icd<-"output\\results_glmnet_atc_icd_T2D.csv"
output_calib_atc_icd<-"output\\glmnet_calib_output_atc_icd_T2D.rds"

data_atc_icd<-data.table(readRDS(input2))


#recode Gender, was 1 male, 2 female to 0 female, 1 male
if(length(which(data_atc_icd$GenderPerson==2))>0){
data_atc_icd$GenderPerson<-car::recode(data_atc_icd$GenderPerson, '"1"=1;"2"=0')
}

#removing ID numbers and converting to sparse matrix
data_atc_icd[,IDPerson:=NULL]
data_atc_icd<-Matrix(data.matrix(data_atc_icd), sparse=T)

#setting all outputs to zero
res <- NULL
res_calib<-NULL
res_calib_full<-NULL

#non indicator variables
add_var<- c("GenderPerson",    "YearBirthPerson")


for(rSeed in 1:10) {
    print(paste0("Starting rSeed ", rSeed))
    
    #controling seed
    set.seed(rSeed)
    
    #manually creating 10 fold
    flds <- createFolds(factor(data_atc_icd[,"poly"]), k = 10, list = FALSE, returnTrain = FALSE)
    
    for(pmax in c(seq(10,100,10), "NDR")) {
    
    for(fnum in 1:10) {
      
      #building training and test set for each created fold, "poly" is output variable
      Y <- data_atc_icd[-which(flds==fnum),"poly"]
      Yt <- data_atc_icd[which(flds==fnum),"poly"]
      X <- data_atc_icd[-which(flds==fnum),!(colnames(data_atc_icd) %in% c("poly"))]
      Xt <- data_atc_icd[which(flds==fnum),!(colnames(data_atc_icd) %in% c("poly"))]  
      
      #names for ICD and ATC codes  
      names_icd<-c(add_var, colnames(X)[grep("^icd|hosp", colnames(X))])
      names_atc<-c(add_var,colnames(X)[grep("^[A-Z][0-9][0-9]", colnames(X))])
      
    
      tmp<-evalGLMNET_PMAX(X[,c(names_atc,names_icd)], Y,
                            Xt[,c(names_atc,names_icd)], Yt,
                            1, paste0("glmnet_atc+icd_MND=",pmax), fnum, 
                            rSeed, rep(1, ncol(X)), pmax=ifelse(pmax=="NDR",length(colnames(X[,c(names_atc,names_icd)])),pmax),
                            weights=rep(1,length(Y)))
       
       res <- rbind(res, tmp[[1]])
       if(length(colnames(tmp[[2]]))==2)   colnames(tmp[[2]])<- c(paste0("P_atc+icd_rSeed=",rSeed, "_MND=", pmax), 
                                                                  paste0("TrueVal_atc+icd_rSeed=",rSeed,"_MND=",pmax))
       if (rSeed ==1) {
       if( is.null(res_calib)) {
         res_calib<-tmp[[2]]
       } else {
       
       if(length(colnames(tmp[[2]]))==2)  res_calib<-rBind(res_calib,tmp[[2]]) 
       }

       }
    }
      
      if (rSeed ==1) {
      if( is.null(res_calib_full)) {
        res_calib_full<-res_calib
      } else {
      
      #if one matrix less rows then other fill with NA for cBind  
      if(length(res_calib[,1])>length(res_calib_full[,1]))  res_calib_full<- bal_matrix_rows(res_calib_full,res_calib)
      if(length(res_calib[,1])<length(res_calib_full[,1]))  res_calib<- bal_matrix_rows(res_calib,res_calib_full)
      
      res_calib_full<-cBind(res_calib_full,res_calib)
      }
      
      saveRDS( res_calib_full,  output_calib_atc_icd)
      res_calib<-NULL
      }
      

    }
    
}

write.csv(res, output_glmnet_atc_icd)
